print_parallel

Function print_parallel 

pub fn print_parallel(w: Walk)
Given a ‘Walk’ struct, traverse it concurrently and print out any relevant outputs. Currently, this only works for a depth of two, which is probably bad.