Walk

Struct Walk 

pub struct Walk {
    pub path: PathBuf,
    /* private fields */
}
The ‘Walk’ struct contains all the information we need to traverse a directory.

Fields

path: PathBuf

Implementations

Source

impl Walk

pub fn print_dir(w: &Walk, total: &Arc<AtomicUsize>)

function to make output from a ‘Walk’, using one thread. It also takes an ‘Arc’ and will add the relevant directory sizes to it.

pub fn set_depth(&mut self, d: u8)

set the maximum depth to display

pub fn set_regex(&mut self, r: Regex)

set the regex for excludes

pub fn set_threshold(&mut self, n: u64)

set the minumum file size

pub fn with_files(&mut self)

include files when printing

pub fn blocks(&mut self)

include files when printing

pub fn artifacts_only(&mut self)

include files when printing

pub fn new(p: PathBuf, n: usize) -> Walk

Create a new ‘Walk’ from a ‘PathBuf’ and the number of processor cores to be used.

pub fn push_subdir( w: &Walk, worker: &mut Worker<Status<Walk>>, total: &Arc<AtomicUsize>, )

This takes a ‘Walk’ and a ‘Worker<Status>’ and executes the walk in parallel, creating new work for each subdirectory. It’s not the most efficient concurrency imaginable, but it’s fast and easy-ish to use. It also takes in an ‘Arc’, which it updates with any file sizes in the directory.