pub struct Walk {
pub path: PathBuf,
/* private fields */
}Expand description
The ‘Walk’ struct contains all the information we need to traverse a directory.
Fields
path: PathBufImplementations
Sourceimpl Walk
impl Walk
Sourcepub fn print_dir(w: &Walk, total: &Arc<AtomicUsize>)
pub fn print_dir(w: &Walk, total: &Arc<AtomicUsize>)
function to make output from a ‘Walk’, using one thread. It also takes an ‘Arc
Sourcepub fn set_threshold(&mut self, n: u64)
pub fn set_threshold(&mut self, n: u64)
set the minumum file size
Sourcepub fn with_files(&mut self)
pub fn with_files(&mut self)
include files when printing
Sourcepub fn artifacts_only(&mut self)
pub fn artifacts_only(&mut self)
include files when printing
Sourcepub fn new(p: PathBuf, n: usize) -> Walk
pub fn new(p: PathBuf, n: usize) -> Walk
Create a new ‘Walk’ from a ‘PathBuf’ and the number of processor cores to be used.
Sourcepub fn push_subdir(
w: &Walk,
worker: &mut Worker<Status<Walk>>,
total: &Arc<AtomicUsize>,
)
pub fn push_subdir( w: &Walk, worker: &mut Worker<Status<Walk>>, total: &Arc<AtomicUsize>, )
This takes a ‘Walk’ and a ‘Worker<Status